<?php
/*******************************************************************************

    Author ......... Jimmy Conner
    Contact ........ jimmy@advcs.org
    Home Site ...... http://www.advcs.org/
    Program ........ Attachment CleanUp
    Version ........ 0.2
    Purpose ........ Deletes any left over temporary files (from attachments)
                     that are over 1 day old

*******************************************************************************/

   global $attachment_dir;
   srand();
   $x = rand(0,9);
   if ($x != 0) return;
   $a = $attachment_dir;
   if (strrpos($a,'/') != strlen($a) && strpos($a,'/') !== false)
      $a .= '/';
   if (strrpos($a,'\\') != strlen($a) && strpos($a,'\\') !== false)
      $a .= '\\';
   $d = @dir($a);
   if (!$d) return;
   $skip = array('.cal','dnscache','.block','.words','.sig','.si','.notes','.php','.abook','.vcf','.pref','.htaccess','default_pref');
   while (false !== ($entry = $d->read())) {
      $delete = false;
      if (@is_file($a . $entry)) {
         $delete = true;
         foreach ($skip as $w) {
            if (strpos(strtolower($entry),$w) !== false)
                $delete = false;
         }
      }
      if ($delete && @filemtime($a . $entry) + 86400 < time())
         @unlink($a . $entry);
   }
   $d->close();
?>